@@ -23,11 +23,12 @@ class DisableEventRulesRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cms', '2019-01-01', 'DisableEventRules','cms')
+		self.set_method('POST')
 
 	def get_RuleNamess(self):
 		return self.get_query_params().get('RuleNamess')
 
-	def set_RuleNamess(self,RuleNamess):
-		for i in range(len(RuleNamess)):	
-			if RuleNamess[i] is not None:
-				self.add_query_param('RuleNames.' + str(i + 1) , RuleNamess[i]);
\ No newline at end of file
+	def set_RuleNamess(self, RuleNamess):
+		for depth1 in range(len(RuleNamess)):
+			if RuleNamess[depth1] is not None:
+				self.add_query_param('RuleNames.' + str(depth1 + 1) , RuleNamess[depth1])
\ No newline at end of file
